pocketpose.models.decoder.posenet - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.models.decoder.posenet`

## Module Contents

### Classes

`PoseNetDecoder` |

class pocketpose.models.decoder.posenet.PoseNetDecoder(output_stride=32, local_maximum_radius=1, threshold=0.5)
  decode_multi_pose(heatmaps, offsets, displacement_fwd, displacement_bwd)
  build_part_with_score_queue(scores)
  score_is_maximum_in_local_window(keypointId, score, heatmapY, heatmapX, scores)
  traverse_to_target_keypoint(keypoints, displacements, direction, scores, offsets)
  get_edge_keypoints(edge_id, direction)
  estimate_target_keypoint_position(edge_id, source_keypoint_id, target_keypoint_id, keypoints, displacements, scores, offsets)
  get_displacement(edge_id, keypoint, displacements)
  get_strided_index_near_point(point, output_stride, displacements)
  get_instance_score(keypoints)
  sigmoid(x)